# coding=iso-8859-15
#
# Newsflash action script.
#
# (c) Sami Visnen 2007
#
# Please modify this file to suit your needs. 
#
# This script runs a PAR 2 parity verification tool for
# .PAR2 files when a batch download has been completed.
# After running the PAR 2 tool it runs an archive tool
# for extracting material from any possible .rar files.
#
# For Windows the applications used are QuickPar and WinRAR.
# For Linux the applications used are par2 and unrar.
#
import os
import re
import flash.host

flash.host.add_log('$Id: action_par2.py,v 1.20 2008/06/25 14:16:34 enska Exp $')

parTool=True
rarTool=True

if os.name == 'posix':
    PAR2  = '/usr/bin/par2'
    UNRAR = '/usr/bin/unrar'
if os.name == 'nt':
    PAR2  = 'C:\\Program Files\\Quick Par\\QuickPar.exe'
    UNRAR = 'C:\\Program Files\\WinRAR\\WinRAR.exe'

if os.path.exists(PAR2) == False:
    flash.host.add_log(PAR2 + ' not found. par2 disabled')
    parTool = False

if os.path.exists(UNRAR) == False:
    flash.host.add_log(UNRAR + ' not found. unrar disabled')
    rarTool = False

def invoke_par2_tool(file):
    """ Invoke the par2 file verification tool for the par2 file specified.
    It assumed that the tool for linux is par2 in /usr/bin/par2.
    For windows QuickPar is assumed """
    flash.host.add_log('Repairing:' + file)
    if os.name == 'posix':

        # see flash/host.py for this system call
        cmd = PAR2 + ' r ' + file
        ret = flash.host.system(cmd, False)
      
    elif os.name == 'nt':
        cmd=PAR2 + ' ' + file
        ret = flash.host.system(cmd, False)


def invoke_rar_tool(file, destination):
    """ Invoke rar file archieve tool for the .rar file specified.
    It is assumed that the tool for linux is unrar in /usr/bin/unrar.
    For windows WinRar is assumed. """
    flash.host.add_log('Extracting:' + file)
    if os.name == 'posix':

        # have to change the working directory temporarily in order
        # to make the unrar extract to the same directory where the source is.
        # this will brake something, the question is just how badly?
        cwd=os.getcwd()
        os.chdir(destination)
        
        # extract to current folder (x) , overwrite existing files (-o+)
        # keep broken files (-kb)
        cmd = UNRAR + ' x -o+ -kb ' + file
        ret = flash.host.system(cmd, False)
        
        # change working dir back to what is supposed to be
        os.chdir(cwd)
        
    elif os.name == 'nt':
        cmd=UNRAR + ' '  + file
        ret = flash.host.system(cmd, False)

def pathfix(location):
    if os.name == 'posix':
        if location[len(location)-1] != '/':
            location = location + '/'
    if os.name == 'nt':
        if location[len(location)-1] != '\\':
            location = location + '\\'
    return location

def escape(path):
    if path[0] != '"':
        path = '"' + path
    if path[len(path)-1] != '"':
        path = path + '"'
    return path

def newsflash_batch_complete(location):
    """ This is the batch_complete action hook function.
    This is called whenever a batch download completes. The argument
    given specifies the location of the batch files (i.e. the folder)
    on the filesystem.
    This kinda assumes the you download every batch into its own folder.
    If this is not the case then you might want to modify the script so that
    it doesn't invoke par2/rar tool for already repaired/extracted files. 
    """
    if parTool==False and rarTool==False:
        return
    if not os.path.exists(location) or not os.path.isdir(location):
        return
    location = pathfix(location)
    names=os.listdir(location)
    if parTool==True:
        # go through the files in the folder and invoke par2 tool for .par2 files
        pattern=re.compile('.*\\.par2$', re.IGNORECASE)
        exlude =re.compile('.*vol[0-9]{1,3}\\+[0-9]{1,3}.*\\.par2$', re.IGNORECASE)
        for i in range(len(names)):
            if re.match(pattern, names[i]) != None:
                if re.match(exlude, names[i]) != None:
                    continue
                file=escape(location + names[i])
                ret=invoke_par2_tool(file)

    if rarTool==True:
        # go through the list again and invoke rar tool for .rar files
        pattern=re.compile('.*\\.rar$', re.IGNORECASE)
        pat2=re.compile('.*part[0-9]*\\.rar$', re.IGNORECASE)
        pat3=re.compile('.*part0?0?1\\.rar$', re.IGNORECASE)
        exclude = re.compile('.*subs?.*\\.rar$', re.IGNORECASE)
        for i in range(len(names)):
            if re.match(pattern, names[i]) == None:
                continue
            if re.match(exclude, names[i]) != None:
                continue
            
            # if the Rar package notation is in the form blabla.part01.rar, blabla.part02.rar
            # only invoke rar on the first part. (i.e. blabla.part01.rar)
            if re.match(pat2, names[i]) != None:
                if re.match(pat3, names[i]) == None:
                    continue
                            
            file=escape(location + names[i])
            ret=invoke_rar_tool(file, location)


