# coding=iso-8859-15

"""
Newsflash extension script example.

This script demonstrates basic extension functionality.
How to use simple widgets such as buttons and listboxes,
and how to handle callbacks for interesting events.

Copyright (c) Sami Visnen 2008
"""

import flash.widget
import flash.host

flash.host.add_log('$Id: extension_example.py,v 1.14 2008/05/22 22:19:52 enska Exp $')

# The extension script must have the window contents referenced
# by a variable called ExtWnd. This is accessed by the host application
# and is then displayed.
ExtWnd=None

# Any script specific data can go here.
ClickCount=0

def extension_deinit():
    """This is the deinit function. This is called when the module
    is being unloaded. This happens only once during the lifetime of the
    whole process just before the process exists. This would is a good place
    to do any possible cleanup. Obviously this function is only called if the
    extension has ever been loaded."""
    pass

def extension_open():
    """This is the open function. This is called once every time
    just before the extension is opened."""
    flash.host.show_msg('extension_open')

def extension_close():
    """This is the close function. This is called once every time
    just after the extension has been closed."""
    pass


def button_1_click():
    """This is the button1 event handler. The host application
    will call this when the button is clicked. """
    flash.host.show_msg("Hello World!");

def button_2_click():
    """This is the button2 event handler. The host application
    will call this when the button is clicked."""
    flash.host.show_msg("You clicked me!")
    global ClickCount
    ExtWnd[3].items.append("You clicked me:" + str(ClickCount))
    ClickCount = ClickCount + 1

def listbox_click(start, end):
    """This is the listbox event handler. The host application
    will call this when the listbox is clicked. Start is the
    start index for the selected items in the listbox. End is
    is the ending index for the selected items. (exlusive)."""
    msg  = 'selected range: ' + str(start) + '-' + str(end) + ' count: ' + str(end-start)
    msg += ' string: ' + ExtWnd[3].items[start]
    flash.host.show_msg(msg)

def input_enter(str):
    """This is the input enter event handler. The host application
    will call this when 'Enter' key is pressed in the input widget.
    Str will the current input string in the widget."""
    flash.host.show_msg("You entered: " + str)
    # clear the string
    ExtWnd[2].value=None
    # add to the listbox
    ExtWnd[3].items.append(str)

# Build the window we want to display to the user
ExtWnd = flash.widget.Window([
    flash.widget.Text( 0, 0, "Here's an example extension!"),
    flash.widget.Text( 0, 1, "Text:"),
    flash.widget.Input(7, 1, "max", None, input_enter),
    flash.widget.List( 0, 3, 'max', -5,
                       ["Hello World!",
                        "Here's another list box string",
                        "one more string",
                        'and finally some special characters... "" & < >'
                        ],
                       flash.widget.LISTBOX_MULTI_SELECT,
                       listbox_click,
                       ),
    flash.widget.Button(0,  -1, "Hello", button_1_click),
    flash.widget.Button(15, -1, "Click me", button_2_click)
    ])


    

