# coding=iso-8859-15

"""
Newsflash media manager extension script.

This extension provides a simple interface
to the file system displaying groups of
certain media files such as .mp3, .ogg,
.avi and .jpe?g files. The files are shown
from the currently configured download location.

My Music    is the list of music files.  (.ogg or .mp3)
My Pictures is the list of picure files. (.jpg or .png)
My videos   is the list of video files.  (.wmv or .avi)
My Files    is the list of all files.

Please modify this script to suit your needs.

Copyright (c) Sami Visnen 2008
"""

import flash.widget
import flash.host
import os
import re

flash.host.add_log('$Id: extension_mediamanager.py,v 1.9 2008/06/18 16:11:05 enska Exp $')

ExtWnd=None
Files=None
Location=None

MY_MUSIC="(.*\\.mp3$)|(.*\\.ogg$)"
MY_VIDEOS="(.*\\.avi$)|(.*\\.wmv$)"
MY_PICTURES="(.*\\.jpg$)|(.*\\.png$)"

def escape(path):
    if path[0] != '"':
        path = '"' + path
    if path[len(path)-1] != '"':
        path = path + '"'
    return path

def extension_open():
    global Location
    Location=flash.host.get_setting('path_bin')
    ExtWnd[1].str = Location

def select_media_type(start, end):
    multisel=False
    regex=None
    if start==0:
        regex=re.compile(MY_MUSIC, re.IGNORECASE)
        multisel=True
    elif start==1:
        regex=re.compile(MY_PICTURES, re.IGNORECASE)
    elif start==2:
        regex=re.compile(MY_VIDEOS, re.IGNORECASE)

    global Files
    global Location
    if Location==None:
        Location=flash.host.get_setting('path_bin')
        if Location==None:
            flash.host.show_msg('Cannot get download location.')
            return

    Files=[] # this is file list with full file paths
    names=[] # this gets shown on the UI
    tree=os.walk(Location)
    for folder in tree:
        path  = folder[0]
        dir   = folder[1]
        files = folder[2]
        lastdir = os.path.split(path)[1]
        for file in files:
            if regex == None or re.match(regex, file) != None:
                Files.append(os.path.join(path, file))
                names.append(os.path.join(lastdir, file))

    ExtWnd[1].str    = Location
    ExtWnd[3].items  = names
    ExtWnd[3].scroll = 1 # enable listbox scrolling
    if multisel:
        ExtWnd[3].selmode = flash.widget.LISTBOX_MULTI_SELECT
    else:
        ExtWnd[3].selmode = flash.widget.LISTBOX_SINGLE_SELECT
    flash.host.show_msg("Showing " + str(len(names)) + " files")
    

def play_file(start, end):
    if Files==None:
        return
    file=Files[start]
    regex=[MY_MUSIC, MY_VIDEOS, MY_PICTURES]
    type=None
    for reg in regex:
        if re.match(re.compile(reg, re.IGNORECASE), file) != None:
            type=reg
            break
    if type==None:
        flash.host.show_msg("Don't know how to open " + file)

    file=escape(file)
    if os.name=='nt':
        if type==MY_MUSIC:
            if os.path.exists('c:\\program files\\winamp\\winamp.exe')==False:
                flash.host.show_msg('WinAMP not found')
                return
            if end - start > 1:
                # clear the playlist with the first selected item.
                flash.host.system('c:\\program files\\winamp\\winamp.exe ' + file, True)
                # skip it and add the rest
                start = start + 1
                for i in range(start, end):
                    file=escape(Files[i])                 
                    flash.host.system('c:\\program files\\winamp\\winamp.exe /ADD ' + file, True)
            else:
                flash.host.system('c:\\program files\\winamp\\winamp.exe ' + file, True)
        elif type==MY_VIDEOS:
            if os.path.exists('c:\\program files\\VideoLAN\\VLC\\vlc.exe')==False:
                flash.host.show_msg('VLC not found')
                return
            cmd='c:\\program files\\VideoLAN\\VLC\\vlc.exe ' + file
            flash.host.system(cmd, True)
        elif type==MY_PICTURES:
            if os.path.exists('c:\\program files\\ACD Systems\\ACDSee\\ACDSee.exe')==False:
                flash.host.host.show_msg('ACDSee not found')
                return
            cmd='c:\\program files\\ACD Systems\\ACDSee\\ACDSee.exe ' + file
            flash.host.system(cmd, True)

    if os.name=='posix':
        if type==MY_MUSIC:
            if os.path.exists('/usr/bin/beep-media-player')==False:
                flash.host.show_msg('beep-media-player not found')
                return
            if end - start > 1:
                # clear the playlist first with the first selected item
                flash.host.system('/usr/bin/beep-media-player ' + file, True)
                # skip it and then add the rest
                start = start + 1
                for i in range(start, end):
                    flash.host.system('/usr/bin/beep-media-player  -e ' + escape(Files[i]), True)
            else:
                # just play this one song.
                flash.host.system('/usr/bin/beep-media-player ' + file, True)
        elif type==MY_VIDEOS:
            if os.path.exists('/usr/bin/vlc')==False:
                flash.host.show_msg('vlc not found')
                return
            cmd='/usr/bin/vlc ' + file + ' &>/dev/null '
            flash.host.system(cmd, True)
        elif type==MY_PICTURES:
            if os.path.exists('/usr/bin/eog')==False:
                flash.host.show_msg('eog not found')
                return
            cmd='/usr/bin/eog ' + file + ' &>/dev/null '
            flash.host.system(cmd, True)


ExtWnd = flash.widget.Window([
    flash.widget.Text(0, 0, "Media manager. Find a file and play!"),
    flash.widget.Text(0, 1, Location),
    flash.widget.List(0, 3, 15, flash.widget.MAX_HEIGHT,
                      ['My Music',
                       'My Pictures',
                       'My Videos',
                       'My Files'],
                      flash.widget.LISTBOX_SINGLE_SELECT, select_media_type),
    flash.widget.List(17, 3, flash.widget.MAX_WIDTH, flash.widget.MAX_HEIGHT, None,
                      flash.widget.LISTBOX_SINGLE_SELECT, play_file)

    ])

select_media_type(0, 0)

