# coding=iso-8859-15
#
# Newsflash Host application interface script.
#
# Copyright (c) Sami Visnen 2008
#
# This script defines some simple helper functions
# that work correctly regarless if the script is
# invoked from/by the Python Shell or by Newsflash
#
import os

PythonShell=True
try:
    import newsflash
    PythonShell=False
except:
    pass

def add_log(str):
    """
    Post a log message to the host application.
    
    If host is the interactive Python shell then this is
    is the same as calling 'print str'.
    """
    if PythonShell:
        print str
    else:
        newsflash.add_log(str)
    
def show_msg(str):
    """
    Show a message in the application's message window.
    
    If host is the Python shell then this is the same as
    calling 'print str'

    """
    if PythonShell:
        print str
    else:
        if str==None:
            str=""
        str = str.encode('iso-8859-15', 'ignore')
        newsflash.show_msg(str)
    
def get_setting(name):
    """
    Get a named setting from the host application.

    Available settings are:
    'path_bin'  - the path where binary items are stored.
    'path_temp' - the path where temporary items are stored.
    'path_log'  - the path where log files are stored.
    'path_data' - the path where data files are stored.
    'version'   - the current application version string
    'home'      - users home folder, e.g. /home/user/
    'exehome'   - the location of the newsflash binary e.g. /usr/bin/
    Important: Currently this function is only available for the application UI thread. If an action script (or any other spawned thread) tries to invoke
    this function a runtime error will be raised.
    
    """
    if PythonShell:
        print 'Running in shell. no settings available'
        return None
    else:
        return newsflash.get_setting(name)

def system(command, fork):
    """
    Execute the specified command.

    This function is much like os.system, except that it
    allows Newsflash to redirect the output from the
    command into a internal buffer for viewing later.
    If fork is True this function creates a child process
    for executing the command and then returns immediately
    without waiting for the child process to finish.
    In this case the return value will be 0.
    If fork is False this function returns only after the invoked command
    has finished running. In this case the return value will be the return
    value of the executed command.
    
    """
    ret=0
    if PythonShell:
        os.system(command)
    else:
        ret=newsflash.system(command, fork)
    return ret
    
    
